Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(268)

Unified Diff: remoting/client/software_video_renderer.h

Issue 836183002: Rename sequence_number to timestamp. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | remoting/client/software_video_renderer.cc » ('j') | remoting/host/chromoting_messages.h » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/client/software_video_renderer.h
diff --git a/remoting/client/software_video_renderer.h b/remoting/client/software_video_renderer.h
index 8327a4356c2309b2d605a6d21b7728d50eb13f4b..984f179921d5d6fa83262c1cfec1b6b61b295cd6 100644
--- a/remoting/client/software_video_renderer.h
+++ b/remoting/client/software_video_renderer.h
@@ -72,8 +72,8 @@ class SoftwareVideoRenderer : public VideoRenderer,
ChromotingStats stats_;
- // Keep track of the most recent sequence number bounced back from the host.
- int64 latest_sequence_number_;
+ // Keep track of the event timestamp bounced back from the host.
+ int64 last_event_timestamp_;
Wez 2015/01/07 23:56:19 s/last/latest
Sergey Ulanov 2015/01/08 17:40:26 Done.
base::WeakPtrFactory<SoftwareVideoRenderer> weak_factory_;
« no previous file with comments | « no previous file | remoting/client/software_video_renderer.cc » ('j') | remoting/host/chromoting_messages.h » ('J')

Powered by Google App Engine
This is Rietveld 408576698